%global gtk2_version 2.20.0
%global dbus_version 1.0
%global gcrypt_version 1.2.2
%global libtasn1_version 0.3.4

Summary:	Framework for managing passwords and other secrets
Name:		mate-keyring
Version:	1.4.0
Release:	8%{?dist}
License:	GPLv2+ and LGPLv2+
Group:		System Environment/Libraries
URL:		http://mate-desktop.org
Source0:	http://pub.mate-desktop.org/releases/1.4/%{name}-%{version}.tar.xz
# http://forums.mate-desktop.org/viewtopic.php?f=2&t=435&sid=5fe96507e9202e1ede654b9c0f8d3bdd
Source1:	start-gnome-keyring-in-mate
Source2:	start-gnome-keyring-in-mate.desktop

# send to upstream
# https://github.com/mate-desktop/mate-keyring/pull/6
# why is mate-keyring-daemon setuid root?
# https://bugzilla.redhat.com/show_bug.cgi?id=668831
Patch4: file-caps.patch
# mate keyring pam module is starting mate-keyring with the wrong SELinux context.
# https://bugzilla.redhat.com/show_bug.cgi?id=684225
Patch5: mate-keyring-1.4.0-pam-selinux.patch

# it's in upstream
# https://github.com/mate-desktop/mate-keyring/commit/95f3999e2718885e1082943dee320ef3e8cf94da
Patch6: mate-keyring_fix_desktop-file.patch


BuildRequires: gtk2-devel >= %{gtk2_version}
BuildRequires: dbus-devel >= %{dbus_version}
BuildRequires: libgcrypt-devel >= %{gcrypt_version}
BuildRequires: libtasn1-devel >= %{libtasn1_version}
BuildRequires: libtasn1-tools
BuildRequires: libmatekeyring-devel
BuildRequires: pam-devel
BuildRequires: mate-common
BuildRequires: libcap-ng-devel
BuildRequires: libselinux-devel

# for smooth transition since the core was split
Requires: libmatekeyring

%description
The mate-keyring session daemon manages passwords and other types of
secrets for the user, storing them encrypted with a main password.
Applications can use the mate-keyring library to integrate with the keyring.

%package devel
Summary: Development files for mate-keyring
License: LGPLv2+
Group: Development/Libraries
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: glib2-devel
# for smooth transition since the core was split
Requires: libmatekeyring-devel

%description devel
The mate-keyring-devel package contains the libraries and
header files needed to develop applications that use mate-keyring.

%package pam
Summary: Pam module for unlocking keyrings
License: LGPLv2+
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
# for /lib64/security
Requires: pam

%description pam
The mate-keyring-pam package contains a pam module that can
automatically unlock the "login" keyring when the user logs in.


%prep
%setup -q -n mate-keyring-%{version}
%patch4 -p1 -b .file-caps
%patch5 -p1 -b .pam-selinux
%patch6 -p1 -b .mate-keyring_fix_desktop-file
NOCONFIGURE=1 ./autogen.sh

%build
%configure \
	--with-pam-dir=/%{_lib}/security \
	--enable-pam \
	--with-gtk=2.0 \
	--disable-gtk-doc \
	--disable-static

# avoid unneeded direct dependencies
sed -i -e 's! -shared ! -Wl,--as-needed\0!g' libtool

make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
find $RPM_BUILD_ROOT -name '*.la' -exec rm -f {} ';'

#start gnome-keyring in mate-session-properties
%{__install} -m 755 %{SOURCE1} $RPM_BUILD_ROOT%{_bindir}/start-gnome-keyring-in-mate
cp -f %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/xdg/autostart/start-gnome-keyring-in-mate.desktop

%find_lang %{name}

%post -p /sbin/ldconfig

%postun
/sbin/ldconfig
if [ $1 -eq 0 ]; then
  /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &>/dev/null || :
fi

%posttrans
/usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &>/dev/null || :


%files -f %{name}.lang
%doc AUTHORS NEWS README COPYING COPYING.LIB
%{_libdir}/lib*.so.*
%dir %{_libdir}/mate-keyring
%dir %{_libdir}/mate-keyring/devel
%{_libdir}/mate-keyring/devel/*.so
%{_libdir}/mate-keyring/standalone/gkm-secret-store-standalone.so
%dir %{_libdir}/pkcs11
%{_libdir}/pkcs11/*.so
%attr(0755,root,root) %caps(cap_ipc_lock=ep) %{_bindir}/mate-keyring-daemon
%{_bindir}/mate-keyring
%{_bindir}/start-gnome-keyring-in-mate
%{_libexecdir}/*
%{_datadir}/dbus-1/services/*.service
%{_datadir}/mategcr
%{_datadir}/mate-keyring
%config(noreplace) %{_sysconfdir}/xdg/autostart/mate-keyring-gpg.desktop
%config(noreplace) %{_sysconfdir}/xdg/autostart/mate-keyring-pkcs11.desktop
%config(noreplace) %{_sysconfdir}/xdg/autostart/mate-keyring-secrets.desktop
%config(noreplace) %{_sysconfdir}/xdg/autostart/mate-keyring-ssh.desktop
%config(noreplace) %{_sysconfdir}/xdg/autostart/start-gnome-keyring-in-mate.desktop
%{_datadir}/MateConf/gsettings/*.convert
%{_datadir}/glib-2.0/schemas/*.gschema.xml

%files devel
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*
%{_includedir}/*
%doc %{_datadir}/gtk-doc

%files pam
/%{_lib}/security/pam_mate_keyring.so


%changelog
* Sun Aug 05 2012 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.4.0-8
- fix rpmlint error unused-direct-shlib-dependency

* Sun Aug 05 2012 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.4.0-7
- fix mixed use of $RPM_BUILD_ROOT & %%{buildroot}
- rename patch to mate
- fix requires in -devel
- fix scriplet sections

* Sat Aug 04 2012 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.4.0-6
- initial build for fedora
- edit start-gnome-keyring-in-mate sources

* Sun Dec 25 2011 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.1.0-1
- mate-file-manager.spec based on gnome-keyring-2.32.0-1.fc14 spec
